<?php
/* ==============================================
	DYNAMIC STYLES, Per Customizer settings
	Skin - Premium WordPress Theme, by NordWood
================================================= */
function skin_dynamic_styles() {		
	wp_enqueue_style( 'skin_dynamic_styles' );
	
	$custom_css = "";
		
/* Content wrapper
==================== */
	if ( ( 800 !== $v = get_theme_mod( 'skin_post_content_width_no_sb', 800 ) ) && $v ) {
		$custom_css .= "
			@media only screen and (min-width:1260px) {
				.content-wrapper-s {
					width: {$v}px;
				}
			}
		";
	}
		
	if ( ( 600 !== $v = get_theme_mod( 'skin_post_content_width', 600 ) ) && $v ) {
		$custom_css .= "
			@media only screen and (min-width:1260px) {
				#main.sidebar-left .content-wrapper-s,
				#main.sidebar-right .content-wrapper-s {
					width: {$v}px;
				}
			}
		";
	}
		
/* Color Scheme
================== */
// Body background
	if ( ( 'f3f3f3' !== $v = get_theme_mod( 'background_color', 'f3f3f3' ) ) && $v ) {
		$custom_css .= "
			.body-bgr,
			body {
				background-color: #{$v};
			}
			
			.body-bgr-to-border {
				border-color: #{$v};
			}
		";
	}
	
// Opacity for the site background image
	if ( ( $v = get_theme_mod( 'skin_bgr_pattern_opacity' ) ) && $v && get_theme_mod( 'background_image' ) ) {
		$clr = '#' . get_theme_mod( 'background_color', 'f3f3f3' );
		$opacity = 0.01*(100 - $v);
		$bgr = skin_hex2rgba( $clr, $opacity );
		
		$custom_css .= "
			.body-pattern {
				background-color: {$bgr};
			}
		";
	}
	
// Gradient background
	$gradient_1 = get_theme_mod( 'skin_gradient_color_1', '#f4d7de' );
	$gradient_2 = get_theme_mod( 'skin_gradient_color_2', '#cecfe7' );
	
	if ( is_page() && skin_get_meta( 'skin_page_gradient_color_1' ) ) {
		$gradient_1 = skin_get_meta( 'skin_page_gradient_color_1' );
	}
	
	if ( is_page() && skin_get_meta( 'skin_page_gradient_color_2' ) ) {
		$gradient_2 = skin_get_meta( 'skin_page_gradient_color_2' );
	}
	
	if ( $gradient_1 && $gradient_2 ) {
		$custom_css .= "
			.gradient-bgr {
				background: linear-gradient( 125deg, {$gradient_1} 0%, {$gradient_2} 100% );
			}
			
			.gradient-bgr-vert {
				background: linear-gradient( to bottom, {$gradient_1} 0%, {$gradient_2} 100% );
			}
		";
	}
	
// Height of the top area
	if ( ( 0 !== $v = get_theme_mod( 'skin_top_gradient_height' ) ) && $v && 'custom-px' === get_theme_mod( 'skin_top_gradient_h', 'custom-px' ) ) {
		$custom_css .= "
			.site-header-bgr.custom-px .pattern,
			.site-header-bgr.custom-px .gradient-bgr,
			.site-header-bgr.custom-px {
				height: {$v}px;
			}
		";
	}
	
// Pattern over the top area
	if ( $v = skin_get_theme_mod_img_src( 'skin_top_pattern' ) ) {
		$custom_css .= "
			.site-header-bgr .pattern {
				background-image:  url('{$v}');
			}
		";
	}
	
// Opacity for the pattern at the top area
	if ( ( 20 !== $v = get_theme_mod( 'skin_top_pattern_opacity' ) ) && $v ) {
		$opacity = 0.01*$v;
		
		$custom_css .= "
			.site-header-bgr .pattern {
				opacity: {$opacity};
			}
		";
	}
	
// Content pad background
	if ( ( '#ffffff' !== $v = get_theme_mod( 'skin_content_pad', '#ffffff' ) ) && $v ) {
		$custom_css .= "
			.content-pad {
				background-color: {$v};
			}
			
			input:-webkit-autofill,
			textarea:-webkit-autofill,
			select:-webkit-autofill {
				-webkit-box-shadow: inset 0 0 0px 9999px {$v};
			}
			
			.content-pad-to-color {
				color: {$v};
			}
			
			.content-pad-to-border {
				border-color: {$v};
			}
			
			.content-pad-to-svg {
				fill: {$v};
			}
		";
		
		if ( SKIN_WOOCOMMERCE_ACTIVE ) {
		$custom_css .= "
			.woocommerce .widget_price_filter .ui-slider .ui-slider-handle {
				background-color: {$v};
			}
			
			.woocommerce input[type='submit'],
			.woocommerce-page .add-to-cart-tiny.button,
			.woocommerce .button {
				background-color: {$v} !important;
			}
			
			.masonry-item article.product .added_to_cart.wc-forward {
				color: {$v};
			}
			
			.woocommerce .out-of-stock,
			.masonry-item article.product .out-of-stock,
			.woocommerce a.remove {
				color: {$v} !important;
			}
		";
		}
	}

// Text color - Main
	if ( ( '#353535' !== $v = get_theme_mod( 'skin_main_txt_color', '#353535' ) ) && $v ) {
		$txt_main_shade = skin_hex2rgba( $v, 0.4 );
		$txt_main_light = skin_hex2rgba( $v, 0.2 );
		$txt_main_pale = skin_hex2rgba( $v, 0.05 );
		
		$custom_css .= "
			body {
				color: {$v};
			}
			
			::placeholder {
				color: {$v};
			}
			
			::-webkit-input-placeholder {
				color: {$v};
			}
			
			:-moz-placeholder {
				color: {$v};
			}
			
			::-moz-placeholder {
				color: {$v};
			}
			
			:-ms-input-placeholder {
				color: {$v};
			}
			
			::-ms-input-placeholder {
				color: {$v};
			}
			
			.txt-color-to-svg .svg-fill,
			#site-footer .social-icon .svg-fill {
				fill: {$v};
			}
			
			.txt-color-to-svg .svg-stroke,
			#site-footer .social-icon .svg-stroke {
				stroke: {$v};
			}
			
			.txt-color-to-bgr,
			.widget_nav_menu li:before,
			.widget_rss li:before,
			.widget_recent_entries li:before,
			.widget_recent_comments li:before,
			.widget_meta li:before,
			.widget_pages li:before,
			.widget_archive li:before {
				background-color: {$v};
			}
			
			select:focus,
			input[type='date']:focus,
			input[type='tel']:focus,
			input[type='number']:focus,
			input[type='email']:focus,
			input[type='url']:focus,
			input[type='text']:focus,
			input[type='password']:focus,
			input[type='submit']:hover,
			textarea:focus {
				border-color: {$v};
				outline: {$v};
			}
			
			.post-details {
				color: {$txt_main_shade};
			}
			
			.txt-color-light-to-border,
			#site-footer .social-icon {
				border-color: {$txt_main_light};
			}
			
			.txt-color-light-to-svg .svg-fill {
				fill: {$txt_main_light};
			}
			
			.txt-color-light-to-svg .svg-stroke {
				stroke: {$txt_main_light};
			}
			
			.txt-color-pale-to-svg .svg-fill {
				fill: {$txt_main_pale};
			}
			
			.txt-color-pale-to-svg .svg-stroke {
				stroke: {$txt_main_pale};
			}
		";
		
		if ( SKIN_WOOCOMMERCE_ACTIVE ) {
		$custom_css .= "			
			.woocommerce input[type='submit'],
			.woocommerce-page .add-to-cart-tiny.button,
			.woocommerce .button {
				color: {$v} !important;
			}
			
			.masonry-item article.product .out-of-stock,
			.masonry-item article.product .add-to-cart-tiny .tooltip:after,
			.masonry-item article.product .added_to_cart.wc-forward,
			.woocommerce .out-of-stock {
				background-color: {$v};
			}
			
			.woocommerce .woocommerce-breadcrumb {
				color: {$txt_main_shade};
			}
			
			.woocommerce #reviews #comments ol.commentlist li .comment-text,
			.woocommerce .select2-selection {
				border-color: {$txt_main_light};
			}
			
			.woocommerce a.remove {
				background-color: {$txt_main_shade};
			}
			
			.woocommerce table td {
				border-color: {$txt_main_light} !important;
			}
	
			.woocommerce .select2-selection .select2-selection__arrow b {
				border-top-color: {$txt_main_light};
			}
		";
		}
	}

// Link color on hover - Main
	if ( ( '#f18597' !== $v = get_theme_mod( 'skin_main_txt_color_hover', '#f18597' ) ) && $v ) {
		$custom_css .= "
			.wp-caption-text a:hover,
			figcaption a:hover,
			.widget_archive li:hover,
			.post-content > ol li a:hover,
			.post-content > ul li a:hover,
			.post-content > p a:hover,
			.masked-txt,
			.mask-txt {
				color: {$v};
			}
	
			.link-hov-main:hover {
				color: {$v};
			}
		";
	}

// Content color on gradient background
	$txt_on_gradient = get_theme_mod( 'skin_txt_on_gradient_color', '#353535' );
	
	if ( is_page() && $p = skin_get_meta( 'skin_page_gradient_txt_color' ) ) {
		$txt_on_gradient = $p;
	}
	
	if ( $txt_on_gradient && '#353535' !== $txt_on_gradient ) {
		$txt_on_gradient_shade = skin_hex2rgba( $txt_on_gradient, 0.4 );
		$txt_on_gradient_light = skin_hex2rgba( $txt_on_gradient, 0.2 );
		$txt_on_gradient_pale = skin_hex2rgba( $txt_on_gradient, 0.05 );
		
		$custom_css .= "
			.txt-on-gradient {
				color: {$txt_on_gradient};
			}
			
			.txt-on-gradient .txt-color-to-svg .svg-fill,
			#site-footer .txt-on-gradient .social-icon .svg-fill {
				fill: {$txt_on_gradient};
			}
			
			.txt-on-gradient .txt-color-to-svg .svg-stroke,
			#site-footer .txt-on-gradient .social-icon .svg-stroke {
				stroke: {$txt_on_gradient};
			}
			
			.txt-on-gradient .txt-color-to-bgr,
			.widget_nav_menu.txt-on-gradient li:before,
			.widget_rss.txt-on-gradient li:before,
			.widget_recent_entries.txt-on-gradient li:before,
			.widget_recent_comments.txt-on-gradient li:before,
			.widget_meta.txt-on-gradient li:before,
			.widget_pages.txt-on-gradient li:before,
			.widget_archive.txt-on-gradient li:before {
				background-color: {$txt_on_gradient};
			}
			
			.txt-on-gradient .post-details {
				color: {$txt_on_gradient_shade};
			}
			
			.txt-on-gradient .txt-color-light-to-border,
			#site-footer .txt-on-gradient .social-icon {
				border-color: {$txt_on_gradient_light};
			}
			
			.txt-on-gradient .txt-color-light-to-svg .svg-fill {
				fill: {$txt_on_gradient_light};
			}
			
			.txt-on-gradient .txt-color-light-to-svg .svg-stroke {
				stroke: {$txt_on_gradient_light};
			}
			
			.txt-on-gradient .txt-color-pale-to-svg .svg-fill {
				fill: {$txt_on_gradient_pale};
			}
			
			.txt-on-gradient .txt-color-pale-to-svg .svg-stroke {
				stroke: {$txt_on_gradient_pale};
			}
		";
	}

// Link color on hover, over gradient background
	$txt_on_gradient_hover = get_theme_mod( 'skin_txt_on_gradient_color_hover', '#ffffff' );
	
	if ( is_page() && $p = skin_get_meta( 'skin_page_gradient_link_color' ) ) {
		$txt_on_gradient_hover = $p;
	}
	
	if ( $txt_on_gradient_hover && '#ffffff' !== $txt_on_gradient_hover ) {
		$custom_css .= "
			.txt-on-gradient .masked-txt,
			.txt-on-gradient .mask-txt {
				color: {$txt_on_gradient_hover};
			}
			
			.txt-on-gradient .link-hov-main:hover {
				color: {$txt_on_gradient_hover};
			}
		";
	}

// Small items
	if ( ( '#f18597' !== $v = get_theme_mod( 'skin_small_item_bgr', '#f18597' ) ) && $v ) {
		$small_item_bgr_light = skin_hex2rgba( $v, 0.5 );
		$small_item_bgr_pale = skin_hex2rgba( $v, 0.2 );
	
		$custom_css .= "
			.select2-container--default .select2-results__option--highlighted[data-selected],
			.select2-container--default .select2-results__option--highlighted[aria-selected],
			.small-item-bgr,
			.widget_calendar tbody td a:before {
				background-color: {$v};
			}
			
			.widget_calendar tbody td#today {
				color: {$v};
			}
			
			.small-item-bgr-to-svg .svg-fill {
				fill: {$v};
			}
			
			.small-item-bgr-light {
				background-color: {$small_item_bgr_light};
			}

			::selection {
				background: {$small_item_bgr_pale};
			}

			::-moz-selection {
				background: {$small_item_bgr_pale};
			}

			::-webkit-selection {
				background: {$small_item_bgr_pale};
			}
			
			mark {
				background: {$small_item_bgr_pale};
			}
		";
		
		if ( SKIN_WOOCOMMERCE_ACTIVE ) {
		$custom_css .= "
			.woocommerce.single-product ul.wc-tabs .skin-tooltip:after,
			.woocommerce-MyAccount-navigation li.is-active a:after,
			.woocommerce.single-product ul.wc-tabs li.active .active-tab-line:after,
			.mini-cart-button-wrapper .skin-tooltip:after,
			.woocommerce .widget_price_filter .ui-slider .ui-slider-range,
			.woocommerce a.remove:hover {
				background-color: {$v};
			}
			
			.woocommerce input[type='submit']:hover,
			.woocommerce-page .add-to-cart-tiny.button:hover,
			.woocommerce .button:hover {
				background-color: {$v} !important;
			}
			
			.woocommerce .widget_layered_nav ul li.chosen a:before,
			.woocommerce .widget_layered_nav_filters ul li a:before,
			.woocommerce p.stars a:before,
			.woocommerce .star-rating:before,
			.woocommerce .star-rating,
			.woocommerce-notice:before,
			.woocommerce-error:before,
			.woocommerce-info:before,
			.woocommerce-message:before {
				color: {$v};
			}
			
			.woocommerce .widget_price_filter .price_slider_wrapper .ui-widget-content {
				background-color: {$small_item_bgr_light};
			}
			
			#add_payment_method #payment,
			.woocommerce-cart #payment,
			.woocommerce-checkout #payment,
			.woocommerce-notice,
			.woocommerce-error,
			.woocommerce-info,
			.woocommerce-message {
				background: {$small_item_bgr_pale};
			}
			
			.woocommerce input[type='submit'],
			.pad-shadow,
			.woocommerce .widget_price_filter .ui-slider .ui-slider-handle,
			.woocommerce-page .add-to-cart-tiny.button,
			.woocommerce .button {
				box-shadow: 0 4px 14px {$small_item_bgr_pale} !important;
			}
		";
		}
	}

	if ( ( '#ffffff' !== $v = get_theme_mod( 'skin_colors_small_item_content', '#ffffff' ) ) && $v ) {
		$custom_css .= "
			.select2-container--default .select2-results__option--highlighted[data-selected],
			.select2-container--default .select2-results__option--highlighted[aria-selected],
			.small-item-color {
				color: {$v};
			}
			
			.small-item-color .svg-fill {
				fill: {$v};
			}
			
			.small-item-color .svg-stroke {
				stroke: {$v};
			}
		";
		
		if ( SKIN_WOOCOMMERCE_ACTIVE ) {
		$custom_css .= "
			.woocommerce input[type='submit']:hover,
			.woocommerce-page .add-to-cart-tiny.button:hover,
			.woocommerce .button:hover {
				color: {$v} !important;
			}
			
			.woocommerce-page .add-to-cart-tiny.button:hover .svg-stroke,
			.woocommerce .button:hover .svg-stroke {
				stroke: {$v} !important;
			}
		";
		}
	}

// Box shadows
	if ( SKIN_WOOCOMMERCE_ACTIVE ) {
		$shadow_color = get_theme_mod( 'skin_woo_shadow_color', '#f18597' );
		$shadow_opacity = get_theme_mod( 'skin_woo_shadow_opacity', 20 ) ? 0.01*get_theme_mod( 'skin_woo_shadow_opacity', 20 ) : 0.2;
		
		if ( $shadow_color || $shadow_opacity ) {
			$shadow_clr = skin_hex2rgba( $shadow_color, $shadow_opacity );
		
			$custom_css .= "
				.woocommerce input[type='submit'],
				.pad-shadow,
				.woocommerce .widget_price_filter .ui-slider .ui-slider-handle,
				.woocommerce-page .add-to-cart-tiny.button,
				.woocommerce .button {
					box-shadow: 0 4px 14px {$shadow_clr} !important;
				}
			";
		}
	}

// Top bar
	if ( ( '#ffffff' !== $v = get_theme_mod( 'skin_top_bar_bgr', '#ffffff' ) ) && $v ) {
		$v_light = skin_hex2rgba( $v, 0.3 );
		$v_medium = skin_hex2rgba( $v, 0.6 );
		
		$custom_css .= "
			.top-bar[data-bgr=\"solid\"],
			.top-bar.edge[data-bgr=\"solid\"],
			.top-bar.desktop .main-menu .sub-menu a:before,
			.top-bar-bgr {
				background-color: {$v};
			}
			
			.top-bar.desktop .main-menu .sub-menu a:hover,
			.top-bar-bgr-to-color {
				color: {$v};
			}
			
			.top-bar-bgr-to-svg .svg-fill {
				fill: {$v};
			}
			
			.top-bar-bgr-medium-to-color {
				color: {$v_medium};
			}
			
			.top-bar-bgr-light-to-border {
				border-color: {$v_light};
			}
			
			.top-bar-bgr-light {
				background-color: {$v_light};
			}
			
			.top-bar-bgr-light-to-svg .svg-fill {
				fill: {$v_light};
			}
		";
	}
	
	if ( ( '#353535' !== $v = get_theme_mod( 'skin_top_bar_txt_color', '#353535' ) ) && $v ) {
		$v_light = skin_hex2rgba( $v, 0.6 );
		$v_pale = skin_hex2rgba( $v, 0.2 );
		
		$custom_css .= "
			.top-bar-color {
				color: {$v};
			}
			
			.top-bar-color-to-bgr {
				background-color: {$v};
			}
			
			.top-bar-color-to-svg .svg-fill {
				fill: {$v};
			}
			
			.top-bar-color-to-svg .svg-stroke {
				stroke: {$v};
			}
			
			.top-bar.desktop .main-menu > ul > li > a > .description {
				color: {$v_light};
			}
			
			.top-bar-color-pale-to-border {
				border-color: {$v_pale};
			}
			
			.top-bar-color-pale-to-svg .svg-stroke {
				stroke: {$v_pale};
			}
		";
	}
	
	if ( ( '#fbe0e5' !== $v = get_theme_mod( 'skin_colors_reading_progress', '#fbe0e5' ) ) && $v ) {
		$custom_css .= "
			.progress {
				background-color: {$v};
			}
		";
	}

// Categories
	$cats = get_categories();
	
	foreach ( $cats as $cat ) {
		$cat_slug = $cat->slug;
		$cat_id = $cat->term_id;
		
		$cat_color = get_theme_mod( 'skin_colors_cat_'.$cat_slug, '#f18597' );
	
		if ( $cat_color ) {
			if ( is_active_widget( false, false, 'categories', true ) ) {
				$custom_css .= "
					.widget_categories li.cat-item-{$cat_id}:before {
						background: {$cat_color};
					}
					
					.widget_categories li.cat-item-{$cat_id}:hover > .qty,
					.widget_categories li.cat-item-{$cat_id}:hover > a {
						color: {$cat_color};
					}
				";
			}
			
			if ( is_category( $cat_id ) ) {
				$custom_css .= "
					.archive-header .cat-title[data-cat-id=\"{$cat_id}\"] {
						background: {$cat_color};
					}
				";
			}
		}
	}

// Woocommerce product categories		
	if ( SKIN_WOOCOMMERCE_ACTIVE ) {
		$cats = get_terms( array(
			'taxonomy' => 'product_cat',
			'hide_empty' => false
		) );
		
		foreach ( $cats as $cat ) {
			$cat_slug = $cat->slug;
			$cat_id = $cat->term_id;
		
			$cat_color = get_theme_mod( 'skin_woo_colors_cat_'.$cat_slug, '#f18597' );
		
			if ( $cat_color ) {
				if ( is_active_widget( false, false, 'woocommerce_product_categories', true ) ) {
					$custom_css .= "				
						.widget_product_categories li.cat-item-{$cat_id}:before {
							background: {$cat_color};
						}
					
						.widget_product_categories li.cat-item-{$cat_id}:hover > .count,
						.widget_product_categories li.cat-item-{$cat_id}:hover > a {
							color: {$cat_color};
						}
					";
				}
			
				if ( is_product_category( $cat_id ) ) {
					$custom_css .= "
						.woocommerce .archive-header .cat-title[data-cat-id=\"{$cat_id}\"] {
							background: {$cat_color};
						}
					";
				}
			}
		}	
	}
		
/* Sticky banner
================== */
	$sticky_banner_h = get_theme_mod( 'skin_sticky_banner_height', 78 );
	
	if ( 1 > $sticky_banner_h ) {
		$sticky_banner_h = 78;
	}	
	
	if ( $sticky_banner_h ) {
		$custom_css .= "
			.sticky-banner img {
				height: {$sticky_banner_h}px;
			}
		";
	}
	
	$sticky_banner_pos = get_theme_mod( 'skin_sticky_banner_position', 'bottom-right' );
	
	if ( 'bottom-right' === $sticky_banner_pos ) {
		$custom_css .= "
			.sticky-banner {
				right: 0; left: auto;
			}
		";		
	}
	
	if ( 'bottom-left' === $sticky_banner_pos ) {
		$custom_css .= "
			.sticky-banner {
				left: 0; right: auto;
			}
		";		
	}
		
/* Typography
================ */
/*
	Split the Google Fonts variant value into array of the font weight and font style values
*/
	if ( ! function_exists( 'skin_adjust_font_variant' ) ) :
		function skin_adjust_font_variant( $font_variant ) {
		// Set the font weight and style initially to "normal"
			$weight_style = array( 'weight' => 'normal', 'style' => 'normal' );
			
		// If the variant value contains the italic styling, split it from the weight
			if ( substr_count( $font_variant, 'italic' ) ) {
				$weight_style['style'] = 'italic';
				
				if ( 0 < strlen( stristr( $font_variant, 'italic', true ) ) ) {
				// If there is a font-weight value before the "italic" substring, update the font weight
					$weight_style['weight'] = stristr( $font_variant, 'italic', true );
				}
				
		// Otherwise, update the font weight only. In case of 'regular', convert it to css friendly value 'normal'
			} else {
				$weight_style['weight'] = ( 'regular' === $font_variant ) ? 'normal' : $font_variant;
			}
			
			return $weight_style;
		}
	endif;
	
/*
	Apply dynamic styles to particular tag, per its typography control
*/
	if ( ! function_exists( 'skin_dynamic_typography' ) ) :
		function skin_dynamic_typography( $control, $target, $def, $important = false ) {
			$typo_def			= explode( '|', $def );
			$font_family_def	= $typo_def[0];
			$font_size_def		= $typo_def[3];
			$line_height_def	= $typo_def[4];
			$letter_spacing_def	= $typo_def[5];
			$text_transform_def	= $typo_def[6];
			$font_variant_def	= $typo_def[1];
			$weight_style_def	= skin_adjust_font_variant( $font_variant_def );
			$font_weight_def	= $weight_style_def['weight'];
			$font_style_def		= $weight_style_def['style'];
			
			$typo			= explode( '|', $control );
			$font_family	= $typo[0];
			$font_size		= $typo[3];
			$line_height	= $typo[4];
			$letter_spacing	= $typo[5];
			$text_transform	= $typo[6];
			$font_variant	= $typo[1];
			$weight_style	= skin_adjust_font_variant( $font_variant );
			$font_weight	= $weight_style['weight'];
			$font_style		= $weight_style['style'];
			
			if ( true === $important ) {
				$css = "
					{$target} {";
						if ( $font_family != $font_family_def ) {
							$css .= "
								font-family: '{$font_family}' !important;";
						}
						
						if ( $font_weight != $font_weight_def ) {
							$css .= "
								font-weight: {$font_weight} !important;";
						}
						
						if ( $font_size != $font_size_def ) {
							$css .= "
								font-size: {$font_size}px !important;";
						}
						
						if ( $line_height != $line_height_def ) {
							$css .= "
								line-height: {$line_height}px !important;";
						}
						
						if ( $letter_spacing != $letter_spacing_def ) {
							$css .= "
								letter-spacing: {$letter_spacing}px !important;";
						}
						
						if ( $text_transform != $text_transform_def ) {
							$css .= "
								text-transform: {$text_transform} !important;";
						}
						
						if ( $font_style != $font_style_def ) {
							$css .= "
								font-style: {$font_style} !important;";
						}
					$css .= "
					}
				";
				
			} else {
				$css = "
					{$target} {";
						if ( $font_family != $font_family_def ) {
							$css .= "
								font-family: '{$font_family}';";
						}
						
						if ( $font_weight != $font_weight_def ) {
							$css .= "
								font-weight: {$font_weight};";
						}
						
						if ( $font_size != $font_size_def ) {
							$css .= "
								font-size: {$font_size}px;";
						}
						
						if ( $line_height != $line_height_def ) {
							$css .= "
								line-height: {$line_height}px;";
						}
						
						if ( $letter_spacing != $letter_spacing_def ) {
							$css .= "
								letter-spacing: {$letter_spacing}px;";
						}
						
						if ( $text_transform != $text_transform_def ) {
							$css .= "
								text-transform: {$text_transform};";
						}
						
						if ( $font_style != $font_style_def ) {
							$css .= "
								font-style: {$font_style};";
						}
					$css .= "
					}
				";
			}
			
			return $css;
		}
	endif;
	
// Main (body)
	if ( $ctrl = get_theme_mod( 'skin_typo_main', 'Quicksand|regular|latin|15|30|0|none|300,regular,500,700' ) ) {
		$def = 'Quicksand|regular|latin|15|30|0|none|300,regular,500,700';
		
		if ( $def != $ctrl ) {
			$custom_css .= skin_dynamic_typography( $ctrl, 'body', $def );
		}
	}

//	h1 heading
	if ( $ctrl = get_theme_mod( 'skin_typo_h1', 'Quicksand|500|latin|40|53|0|none|300,regular,500,700' ) ) {
		$def = 'Quicksand|500|latin|40|53|0|none|300,regular,500,700';
		
		if ( $def != $ctrl ) {		
			$custom_css .= skin_dynamic_typography( $ctrl, 'h1', $def );
			$custom_css .= skin_dynamic_typography( $ctrl, '.archive-header .search-field', $def );
			$custom_css .= skin_dynamic_typography( $ctrl, '#search-overlay .search-field', $def );
		}
	}

//	h2 heading
	if ( $ctrl = get_theme_mod( 'skin_typo_h2', 'Quicksand|500|latin|32|40|0|none|300,regular,500,700' ) ) {
		$def = 'Quicksand|500|latin|32|40|0|none|300,regular,500,700';
		
		if ( $def != $ctrl ) {
			$custom_css .= skin_dynamic_typography( $ctrl, 'h2', $def );
		}
	}

//	h3 heading
	if ( $ctrl = get_theme_mod( 'skin_typo_h3', 'Quicksand|500|latin|21|30|0|none|300,regular,500,700' ) ) {
		$def = 'Quicksand|500|latin|21|30|0|none|300,regular,500,700';
		
		if ( $def != $ctrl ) {		
			$custom_css .= skin_dynamic_typography( $ctrl, 'h3', $def );
			$custom_css .= skin_dynamic_typography( $ctrl, '.widget_search .search-field', $def );
			$custom_css .= skin_dynamic_typography( $ctrl, '.widget_product_search .search-field', $def );
		}
	}

//	h4 heading
	if ( $ctrl = get_theme_mod( 'skin_typo_h4', 'Quicksand|500|latin|18|26|0|none|300,regular,500,700' ) ) {
		$def = 'Quicksand|500|latin|18|26|0|none|300,regular,500,700';
		
		if ( $def != $ctrl ) {
			$custom_css .= skin_dynamic_typography( $ctrl, 'h4', $def );
		}
	}

//	h5 heading
	if ( $ctrl = get_theme_mod( 'skin_typo_h5', 'Quicksand|500|latin|15|22|0|none|300,regular,500,700' ) ) {
		$def = 'Quicksand|500|latin|15|22|0|none|300,regular,500,700';
		
		if ( $def != $ctrl ) {		
			$custom_css .= skin_dynamic_typography( $ctrl, 'h5', $def );
			$custom_css .= skin_dynamic_typography( $ctrl, '.woocommerce-page .add-to-cart-tiny.button', $def, true );
			$custom_css .= skin_dynamic_typography( $ctrl, '.woocommerce input[type="submit"]', $def, true );
			$custom_css .= skin_dynamic_typography( $ctrl, '.woocommerce .button', $def, true );
		}
	}

//	h6 heading
	if ( $ctrl = get_theme_mod( 'skin_typo_h6', 'Quicksand|500|latin|10|18|1|none|300,regular,500,700' ) ) {
		$def = 'Quicksand|500|latin|10|18|1|none|300,regular,500,700';
		
		if ( $def != $ctrl ) {
			$custom_css .= skin_dynamic_typography( $ctrl, 'h6', $def );
		}
	}

//	Welcome message
	if ( $ctrl = get_theme_mod( 'skin_typo_welcome', 'Quicksand|500|latin|40|53|0|none|300,regular,500,700' ) ) {
		$def = 'Quicksand|500|latin|40|53|0|none|300,regular,500,700';
		
		if ( $def != $ctrl ) {
			$custom_css .= skin_dynamic_typography( $ctrl, '.welcome-mssg', $def );
		}
	}

//	Drop caps
	if ( $ctrl = get_theme_mod( 'skin_typo_dropcaps', 'Quicksand|500|latin|32|30|0|none|300,regular,500,700' ) ) {
		$def = 'Quicksand|500|latin|32|30|0|none|300,regular,500,700';
		
		if ( $def != $ctrl ) {		
			$custom_css .= skin_dynamic_typography( $ctrl, '.page #main .drop-caps .post-content > p:first-of-type::first-letter', $def );
			$custom_css .= skin_dynamic_typography( $ctrl, '.single #main .drop-caps .post-content > p:first-of-type::first-letter', $def );
		}
	}

//	Blockquote
	if ( $ctrl = get_theme_mod( 'skin_typo_blockquote', 'Quicksand|500|latin|21|30|0|none|300,regular,500,700' ) ) {
		$def = 'Quicksand|500|latin|21|30|0|none|300,regular,500,700';
		
		if ( $def != $ctrl ) {
			$custom_css .= skin_dynamic_typography( $ctrl, '.post-content blockquote .quotation', $def );
		}
	}

//	Details
	if ( $ctrl = get_theme_mod( 'skin_typo_details', 'Quicksand|500|latin|12|18|0|none|300,regular,500,700' ) ) {
		$def = 'Quicksand|500|latin|12|18|0|none|300,regular,500,700';
		
		if ( $def != $ctrl ) {
			$custom_css .= skin_dynamic_typography( $ctrl, '.post-details', $def );
		}
	}

//	Small text
	if ( $ctrl = get_theme_mod( 'skin_typo_small_text', 'Quicksand|regular|latin|13|24|0|none|300,regular,500,700' ) ) {
		$def = 'Quicksand|regular|latin|13|24|0|none|300,regular,500,700';
		
		if ( $def != $ctrl ) {
			$custom_css .= skin_dynamic_typography( $ctrl, '.small-text', $def );
		}
	}

//	Main menu
	if ( $ctrl = get_theme_mod( 'skin_typo_topbar', 'Quicksand|500|latin|17|30|0|none|300,regular,500,700' ) ) {
		$def = 'Quicksand|500|latin|17|30|0|none|300,regular,500,700';
		
		if ( $def != $ctrl ) {
			$custom_css .= skin_dynamic_typography( $ctrl, '.top-bar.desktop', $def );
		}
	}
	
//	Minify dynamic css, if needed
	if ( true === get_theme_mod( 'skin_opt_minify_dynamic_inline_css', false ) ) {
		$dynamic_css = skin_minify_inline_css( $custom_css );
		
	} else {
		$dynamic_css = $custom_css;
	}
	
// Apply all the styles above
	wp_add_inline_style( 'skin_dynamic_styles', $dynamic_css );
}

add_action( 'wp_enqueue_scripts', 'skin_dynamic_styles' );
?>