<?php
/* ==============================================
	CUSTOM FIELDS FOR USERS
	Skin - Premium WordPress Theme, by NordWood
================================================= */
	if ( ! function_exists( 'skin_add_user_profile_fields' ) ) :
		function skin_add_user_profile_fields( $user ) {
			$img_id = get_the_author_meta( 'skin_user_img', $user->ID );
	?>
		<table class="form-table">
			<tr>
				<th>
					<label for="skin_user_position"><?php esc_html_e( 'Position', 'skin' ); ?></label>
				</th>
				<td>
					<input type="text" class="regular-text"
						name="skin_user_position"
						id="skin_user_position"
						value="<?php echo esc_attr( get_the_author_meta( 'skin_user_position', $user->ID ) ); ?>" />
						
					<p class="description"><?php esc_html_e( 'If populated, it will be displayed near author\'s name in bio, archive and author\'s slider.', 'skin' ); ?></p>
				</td>
			</tr>
			
			<tr>
				<th>
					<label for="skin_user_img"><?php esc_html_e( 'User image', 'skin' ); ?></label>
				</th>
				 
				<td>
					<div class="img-upload-wrapper clearfix">
						<div class="img-preview"><?php
							if ( '' !== $img_id ) :
								echo wp_get_attachment_image( $img_id, 'thumbnail' );
							endif;
						?></div>
						
						<input type="hidden" class="img-id"
							name="skin_user_img"
							id="skin_user_img"						
							value="<?php echo esc_attr( get_the_author_meta( 'skin_user_img', $user->ID ) ); ?>"
						>				
						
						<input type="button" class="button upload-img <?php if ( '' !== $img_id ) { echo 'hidden'; } ?>"
							name="skin_user_img_upload"
							id="skin_user_img_upload"
							value="<?php esc_attr_e( 'Upload image', 'skin' ); ?>"
						>
						
						<input type="button" class="button remove-img <?php if ( '' === $img_id ) { echo 'hidden'; } ?>"
							name="skin_user_img_remove"
							id="skin_user_img_remove"
							value="<?php esc_attr_e( 'Remove image', 'skin' ); ?>"
						>
						
						<p class="description"><?php esc_html_e( 'If no image is uploaded, gravatar will be used.', 'skin' ); ?></p>
					</div>
					<br>
					<label for="skin_show_avatar_in_archive">
						<input name="skin_show_avatar_in_archive" type="checkbox" id="skin_show_avatar_in_archive" value="show" <?php checked( get_the_author_meta( 'skin_show_avatar_in_archive', $user->ID ), "show" ); ?> />
						<?php esc_html_e( 'Show user image in author\'s archive', 'skin' ); ?>
					</label>
				</td>
			</tr>
		</table>
	<?php
		}
	endif;	
	
	add_action( 'show_user_profile', 'skin_add_user_profile_fields', 10, 1 );
	add_action( 'edit_user_profile', 'skin_add_user_profile_fields', 10, 1 );
	
/* Save custom fields to users */
	if ( ! function_exists( 'skin_update_user_profile_fields' ) ) :
		function skin_update_user_profile_fields( $user_id ) {
			if ( current_user_can( 'edit_user', $user_id ) ) {
				update_user_meta( $user_id, 'skin_user_position', $_POST['skin_user_position'] );
				update_user_meta( $user_id, 'skin_user_img', $_POST['skin_user_img'] );
				update_user_meta( $user_id, 'skin_show_avatar_in_archive', empty( $_POST['skin_show_avatar_in_archive'] ) ? 0 : "show" );
			}
		}
	endif;
	
	add_action( 'edit_user_profile_update', 'skin_update_user_profile_fields' );
	add_action( 'personal_options_update', 'skin_update_user_profile_fields' );
		
/* Enqueue scripts for User screens */
	add_action( 'admin_enqueue_scripts', 'skin_users_scripts' );
	
	if ( ! function_exists( 'skin_users_scripts' ) ):
		function skin_users_scripts( $hook ) {
			if ( 'user-new.php' != $hook && 'user-edit.php' != $hook && 'profile.php' != $hook ) {
				return;
			}
			
			wp_enqueue_media();
			wp_enqueue_script( 'skin_img_upload' );
		}
	endif;
?>